
.. index:: setup

.. blogpost::
    :title: Install a shortcut with setup.py
    :keywords: setup, entry points, scripts, entrypoints
    :date: 2015-08-17
    :categories: setup

    This is described by
    `Explain Python entry points? <http://stackoverflow.com/questions/774824/explain-python-entry-points>`_.
    Example: `setup.py <https://github.com/sdpython/pymyinstall/blob/master/setup.py>`_.
